#[non_exhaustive]pub struct Stream {Show 15 fields
pub game_id: CategoryId,
pub game_name: String,
pub id: StreamId,
pub language: String,
pub is_mature: bool,
pub started_at: Timestamp,
pub tag_ids: Vec<TagId>,
pub tags: Vec<String>,
pub thumbnail_url: String,
pub title: String,
pub type_: StreamType,
pub user_id: UserId,
pub user_name: DisplayName,
pub user_login: UserName,
pub viewer_count: usize,
}Available on crate feature
helix only.Expand description
Return Values for Get Streams
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.game_id: CategoryIdID of the game being played on the stream.
game_name: StringName of the game being played.
id: StreamIdStream ID.
language: StringStream language.
is_mature: boolIndicates if the broadcaster has specified their channel contains mature content that may be inappropriate for younger audiences.
started_at: TimestampUTC timestamp.
tag_ids: Vec<TagId>👎Deprecated:
use tags instead
Shows tag IDs that apply to the stream.
The tags applied to the stream.
thumbnail_url: StringThumbnail URL of the stream. All image URLs have variable width and height. You can replace {width} and {height} with any values to get that size image
title: StringStream title.
type_: StreamTypeStream type: “live” or “” (in case of error).
user_id: UserIdID of the user who is streaming.
user_name: DisplayNameDisplay name corresponding to user_id.
user_login: UserNameLogin of the user who is streaming.
viewer_count: usizeNumber of viewers watching the stream at the time of the query.